@@ -1,13 +1,12 @@
 """Create a RequestModel to execute a Gradient Map analysis."""
 
-from typing import Dict
-
 from aidkitcli.core.analyses.gradient_map import gradient_map as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def gradient_map(data: str, model: str,
-                 title: str = "Config Gradient Map Analysis") -> Dict[str, int]:
+                 title: str = "Config Gradient Map Analysis") -> Report:
     """
     Visualize which inputs affect the model's prediction the most in a plot
     that shows the development of the gradient across the data points.
@@ -30,4 +29,4 @@ def gradient_map(data: str, model: str,
         model=model,
         title=title
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
