@@ -1,13 +1,12 @@
 """Create a RequestModel to execute a Data Investigation analysis."""
 
-from typing import Dict
-
 from aidkitcli.core.analyses.data_investigation import data_investigation as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def data_investigation(data: str, model: str,
-                       title: str = "Config Data Investigation Analysis") -> Dict[str, int]:
+                       title: str = "Config Data Investigation Analysis") -> Report:
     """
     Analyze the statistics and distribution of the provided data through five
     plots and the value of four metrics.
@@ -53,4 +52,4 @@ def data_investigation(data: str, model: str,
         data=data,
         model=model,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
