@@ -1,9 +1,8 @@
 """Create a RequestModel to execute an Aggregated Constant corruption."""
 
-from typing import Dict
-
 from aidkitcli.core.analyses.aggregated_constant import aggregated_constant as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def aggregated_constant(data: str,
@@ -15,7 +14,7 @@ def aggregated_constant(data: str,
                         perturbation_length: int = 100000,
                         number_of_constants: int = 10,
                         title: str = "Config Aggregated Constant Corruption"
-                        ) -> Dict[str, int]:
+                        ) -> Report:
     """
     Execute an Aggregated Constant Corruption and return a plot showing the
     performance of the model on the corrupted data.
@@ -60,4 +59,4 @@ def aggregated_constant(data: str,
         perturbation_length=perturbation_length,
         number_of_constants=number_of_constants,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
