@@ -1,8 +1,9 @@
 """Create a RequestModel to execute a Black-Box attack."""
-from typing import Dict, List
+from typing import List
 
 from aidkitcli.core.analyses.blackbox import blackbox as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def blackbox(data: str,
@@ -17,7 +18,7 @@ def blackbox(data: str,
              mask: List[int] = [],
              step_length: List[int] = [],
              title: str = "Config Black-Box Attack"
-             ) -> Dict[str, int]:
+             ) -> Report:
     """
     Execute a Black-Box Attack that creates one perturbation per file in the
     data set. The perturbation is then added to every eligible data point in
@@ -72,4 +73,4 @@ def blackbox(data: str,
         mask=mask,
         step_length=step_length,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
