@@ -1,10 +1,9 @@
 """Create a RequestModel to execute a Constant corruption."""
 from typing import Union
 
-from typing import Dict
-
 from aidkitcli.core.analyses.constant import constant as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def constant(data: str,
@@ -14,7 +13,7 @@ def constant(data: str,
              start_index: int = 0,
              perturbation_length: int = 100000,
              title: str = "Config Constant Corruption"
-             ) -> Dict[str, int]:
+             ) -> Report:
     """
     Execute a Constant Corruption and return a plot showing the performance of
     the model on the corrupted data.
@@ -47,4 +46,4 @@ def constant(data: str,
         start_index=start_index,
         perturbation_length=perturbation_length,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
