@@ -1,8 +1,9 @@
 """Create a RequestModel to execute a Correlation attack."""
-from typing import Dict, List
+from typing import List
 
 from aidkitcli.core.analyses.correlation import correlation as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def correlation(data: str,
@@ -14,7 +15,7 @@ def correlation(data: str,
                 mask: List[int] = [],
                 step_length: List[int] = [],
                 title: str = "Config Correlation Attack"
-                ) -> Dict[str, int]:
+                ) -> Report:
     """
     Execute a Correlation Attack that creates a perturbation per eligible data
     point in each file of the data set and return a plot showing the performance
@@ -58,4 +59,4 @@ def correlation(data: str,
         mask=mask,
         step_length=step_length,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
