@@ -1,8 +1,9 @@
 """Create a RequestModel to execute an FGSM attack."""
-from typing import Dict, List
+from typing import List
 
 from aidkitcli.core.analyses.fgsm import fgsm as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def fgsm(data: str,
@@ -15,7 +16,7 @@ def fgsm(data: str,
          mask: List[int] = [],
          step_length: List[int] = [],
          title: str = "Config FGSM Attack"
-         ) -> Dict[str, int]:
+         ) -> Report:
     """
     Execute a Fast Gradient Sign Method Attack that creates a perturbation per
     eligible data point in each file of the data set and return a plot showing
@@ -74,4 +75,4 @@ def fgsm(data: str,
         mask=mask,
         step_length=step_length,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
