@@ -1,19 +1,12 @@
 """Create a RequestModel to execute a Key Robustness Indicator analysis."""
-from typing import Dict, List, Union
+from typing import List, Union
 
+from aidkitcli.core.analyses.kri import BlackboxDistribution, ConstantDistribution, CorrelationDistribution, \
+    Distribution, FGSMDistribution, IncreaseDistribution, PeakDistribution, RandomDistribution, \
+    RelativeConstantDistribution
 from aidkitcli.core.analyses.kri import kri as request_factory
-from aidkitcli.core.analyses.kri import (
-    Distribution,
-    ConstantDistribution,
-    RelativeConstantDistribution,
-    IncreaseDistribution,
-    RandomDistribution,
-    FGSMDistribution,
-    CorrelationDistribution,
-    PeakDistribution,
-    BlackboxDistribution
-)
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def constant_distribution_factory(variable_name: str,
@@ -406,7 +399,7 @@ def kri(data: str, model: str,
         p_x: List[float], p_cond: List[float],
         distributions: List[Distribution],
         title: str = "Config KRI Analysis"
-        ) -> Dict[str, int]:
+        ) -> Report:
     """
     Calculate the key robustness indicators (KRI) of the model on the basis of
     a given data set and realistic distributions for the deployment context.
@@ -463,4 +456,4 @@ def kri(data: str, model: str,
         p_cond=p_cond,
         distributions=distributions
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
