@@ -1,9 +1,8 @@
 """Create a RequestModel to execute a Relative Constant corruption."""
 
-from typing import Dict
-
 from aidkitcli.core.analyses.relative_constant import relative_constant as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def relative_constant(data: str,
@@ -13,7 +12,7 @@ def relative_constant(data: str,
                       start_index: int = 0,
                       perturbation_length: int = 100000,
                       title: str = "Config Relative Constant Corruption"
-                      ) -> Dict[str, int]:
+                      ) -> Report:
     """
     Execute a Relative Constant Corruption and return a plot showing the
     performance of the model on the corrupted data.
@@ -46,4 +45,4 @@ def relative_constant(data: str,
         start_index=start_index,
         perturbation_length=perturbation_length,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
