@@ -1,9 +1,9 @@
 """Create a RequestModel for a Key Robustness Indicator analysis."""
+from dataclasses import asdict, dataclass
 from typing import List, Union
-from dataclasses import dataclass, asdict
 
-from aidkitcli.core.utils import create_toml
 from aidkitcli.core.request_model import RequestModel
+from aidkitcli.core.utils import create_toml
 from aidkitcli.data_access.stored_model_access import load_stored_model
 
 
@@ -29,13 +29,12 @@ class RelativeConstantDistribution(Distribution):
 
 
 @dataclass
-class IncDecDistribution(Distribution):
+class IncreaseDistribution(Distribution):
     variable_name: str
-    factor: float
     start_constant: float
     end_constant: float
     step_length: int
-    name: str = "inc_dec"
+    name: str = "increase"
 
 
 @dataclass
@@ -155,19 +154,19 @@ def relative_constant_distribution_factory(variable_name: str,
     return distribution
 
 
-def inc_dec_distribution_factory(variable_name: str,
-                                 step_length: int,
-                                 start_constant: float,
-                                 end_constant: float,
-                                 start_index: int = 0,
-                                 perturbation_length: int = 100000
-                                 ) -> IncDecDistribution:
+def increase_distribution_factory(variable_name: str,
+                                  step_length: int,
+                                  start_constant: float,
+                                  end_constant: float,
+                                  start_index: int = 0,
+                                  perturbation_length: int = 100000
+                                  ) -> IncreaseDistribution:
     """
     Create a distribution object containing all the parameters needed to
-    execute a Increasing - Decreasing Corruption. This object can then be fed
+    execute a Increase Corruption. This object can then be fed
     to the KRI function to determine a robustness risk score.
 
-    When an Increasing - Decreasing Corruption is executed, the values of the
+    When an Increase Corruption is executed, the values of the
     selected variable are first set to the start_constant value and then
     changed every step_length data points in the file. Depending on whether
     end_constant is bigger or smaller than start_constant, the values are
@@ -187,17 +186,11 @@ def inc_dec_distribution_factory(variable_name: str,
     :param start_index: data points before this index will not be perturbed
     :param perturbation_length: number of data points perturbed
     """
-    if start_constant < end_constant:
-        factor = 1.0
-    else:
-        factor = -1.0
-
-    distribution = IncDecDistribution(
+    distribution = IncreaseDistribution(
         variable_name=variable_name,
         step_length=step_length,
         start_constant=start_constant,
         end_constant=end_constant,
-        factor=factor,
         start_index=start_index,
         perturbation_length=perturbation_length,
         saver=1
@@ -500,7 +493,7 @@ def kri(data: str, model: str,
     and adversarial attacks:
         - "constant" - Constant Corruption
         - "relative_constant" - Relative Constant Corruption
-        - "inc_dec" - Increase/Decrease Corruption
+        - "increase" - Increase/Decrease Corruption
         - "random" - Random Corruption
         - "fgsm" - Fast Gradient Sign Method Attack
         - "correlation" - Correlation Attack
@@ -514,17 +507,17 @@ def kri(data: str, model: str,
     :param data: name of the data set
     :param model: path to the TOML file that contains the model information
     :param p_x: list of the probabilities of occurrence of a data file in the
-    deployment context, the length of the list must be equal to the number of
-    data files in the provided data set and the probabilities must sum up to 1
+        deployment context, the length of the list must be equal to the number of
+        data files in the provided data set and the probabilities must sum up to 1
     :param p_cond: list of the probabilities of each distribution (corruption/
-    attack) given a data set, the length of the list must be equal to the
-    number of distributions and the probabilities must sum up to 1
+        attack) given a data set, the length of the list must be equal to the
+        number of distributions and the probabilities must sum up to 1
     :param distributions: list of the distributions (corruptions/attacks) for
-    the KRI analysis, each distribution is created by its corresponding
-    factory method <distribution_name>_distribution_factory
+        the KRI analysis, each distribution is created by its corresponding
+        factory method <distribution_name>_distribution_factory
     :param title: title of the configuration (default: "Config KRI Analysis")
     :return: a RequestModel instance containing all the information needed to
-    execute a Key Robustness Indicator analysis
+        execute a Key Robustness Indicator analysis
     """
     stored_model = load_stored_model(path=model)
 
