@@ -8,5 +8,5 @@ You only need to configure and upload your model once and then you'll be able
 to reuse it for future quality analyses (:ref:`example-store-upload-model`).
 """
 from aidkitcli.core.utils import store_model
-from aidkitcli.core.stored_model import DataColumn
+from aidkitcli.core.stored_model import InputFeatures
 from aidkitcli.data_access.upload import upload_model, list_models
